@@ -26,7 +26,10 @@ Changelog
 0.0.21:fix: rename api name
 0.0.22:fix: fix core module
 0.0.23:fix: fix core module
+0.0.24:fix: fix chinese character params in api
+0.0.25:test: test
 """
 
-__version__ = "0.0.23"
+__title__ = "AKTools"
+__version__ = "0.0.25"
 __author__ = "Albert King"
